@@ -36,6 +36,9 @@ namespace xsimd
 
     public:
 
+        using self_type = batch<int32_t, 4>;
+        using base_type = simd_batch<self_type>;
+
         batch();
         explicit batch(int32_t d);
         batch(int32_t d0, int32_t d1, int32_t d2, int32_t d3);
@@ -61,11 +64,11 @@ namespace xsimd
         batch& load_aligned(const int64_t* src);
         batch& load_unaligned(const int64_t* src);
 
-        batch& load_aligned(const char* src);
-        batch& load_unaligned(const char* src);
+        batch& load_aligned(const int8_t* src);
+        batch& load_unaligned(const int8_t* src);
 
-        batch& load_aligned(const unsigned char* src);
-        batch& load_unaligned(const unsigned char* src);
+        batch& load_aligned(const uint8_t* src);
+        batch& load_unaligned(const uint8_t* src);
 
         void store_aligned(float* dst) const;
         void store_unaligned(float* dst) const;
@@ -79,11 +82,16 @@ namespace xsimd
         void store_aligned(int64_t* dst) const;
         void store_unaligned(int64_t* dst) const;
 
-        void store_aligned(char* dst) const;
-        void store_unaligned(char* dst) const;
+        void store_aligned(int8_t* dst) const;
+        void store_unaligned(int8_t* dst) const;
 
-        void store_aligned(unsigned char* dst) const;
-        void store_unaligned(unsigned char* dst) const;
+        void store_aligned(uint8_t* dst) const;
+        void store_unaligned(uint8_t* dst) const;
+
+        using base_type::load_aligned;
+        using base_type::load_unaligned;
+        using base_type::store_aligned;
+        using base_type::store_unaligned;
 
         int32_t operator[](std::size_t index) const;
 
@@ -203,7 +211,7 @@ namespace xsimd
         return *this;
     }
 
-    inline batch<int32_t, 4>& batch<int32_t, 4>::load_aligned(const char* src)
+    inline batch<int32_t, 4>& batch<int32_t, 4>::load_aligned(const int8_t* src)
     {
         int8x8_t tmp = vld1_s8((const int8_t*)src);
         int16x8_t tmp2 = vmovl_s8(tmp);
@@ -212,12 +220,12 @@ namespace xsimd
         return *this;
     }
 
-    inline batch<int32_t, 4>& batch<int32_t, 4>::load_unaligned(const char* src)
+    inline batch<int32_t, 4>& batch<int32_t, 4>::load_unaligned(const int8_t* src)
     {
         return load_aligned(src);
     }
 
-    inline batch<int32_t, 4>& batch<int32_t, 4>::load_aligned(const unsigned char* src)
+    inline batch<int32_t, 4>& batch<int32_t, 4>::load_aligned(const uint8_t* src)
     {
         uint8x8_t tmp = vld1_u8((const uint8_t*)src);
         uint16x8_t tmp2 = vmovl_u8(tmp);
@@ -226,7 +234,7 @@ namespace xsimd
         return *this;
     }
 
-    inline batch<int32_t, 4>& batch<int32_t, 4>::load_unaligned(const unsigned char* src)
+    inline batch<int32_t, 4>& batch<int32_t, 4>::load_unaligned(const uint8_t* src)
     {
         return load_aligned(src);
     }
@@ -271,7 +279,7 @@ namespace xsimd
         store_aligned(dst);
     }
 
-    inline void batch<int32_t, 4>::store_aligned(char* dst) const
+    inline void batch<int32_t, 4>::store_aligned(int8_t* dst) const
     {
         int16x4_t tmp2 = vmovn_s32(m_value);
         int16x8_t tmp3 = vcombine_s16(tmp2, vdup_n_s16(0));
@@ -279,12 +287,12 @@ namespace xsimd
         vst1_s8((int8_t*)dst, tmp4);
     }
 
-    inline void batch<int32_t, 4>::store_unaligned(char* dst) const
+    inline void batch<int32_t, 4>::store_unaligned(int8_t* dst) const
     {
         store_aligned(dst);
     }
 
-    inline void batch<int32_t, 4>::store_aligned(unsigned char* dst) const
+    inline void batch<int32_t, 4>::store_aligned(uint8_t* dst) const
     {
         uint16x4_t tmp2 = vmovn_u32(m_value);
         uint16x8_t tmp3 = vcombine_u16(tmp2, vdup_n_u16(0));
@@ -292,7 +300,7 @@ namespace xsimd
         vst1_u8((uint8_t*)dst, tmp4);
     }
 
-    inline void batch<int32_t, 4>::store_unaligned(unsigned char* dst) const
+    inline void batch<int32_t, 4>::store_unaligned(uint8_t* dst) const
     {
         store_aligned(dst);
     }
